<?php
/**
 * Adds theme box size option to posts.
 *
 * @package WordPress
 * @subpackage Collect
 * @since Collect 1.0
 */
class Collect_Metaboxes {
	public function __construct() {
		add_action( 'add_meta_boxes', array( $this, 'add_custom_metabox' ) );
		add_action( 'pre_post_update', array( $this, 'pre_post_update' ) );
	}

	/**
	 * Add option for full width posts & pages
	 *
	 * This function is attached to the 'add_meta_boxes' action hook.
	 *
	 * @since 1.0.0
	 */
	public function add_custom_metabox() {
		add_meta_box( 'theme-box-size', __( 'Box Size', 'collect' ), array( $this, 'box_size' ), 'post', 'side' );
	}

	public function box_size( $post ) {
		$box_size = get_post_meta( $post->ID, 'collect_box_size', true );

		// Use nonce for verification
		wp_nonce_field( 'collect_nonce', 'collect_nonce' );
		?>

		<label for="collect_box_size"><?php _e( 'Size', 'collect' ); ?></label>&nbsp;
		<select id="collect_box_size" name="collect_box_size">
			<option value="collect-square" <?php selected( $box_size, 'collect-square' ); ?>><?php _e( 'Square', 'collect'); ?></option>
			<option value="collect-wide" <?php selected( $box_size, 'collect-wide' ); ?>><?php _e( 'Wide', 'collect'); ?></option>
			<option value="collect-tall" <?php selected( $box_size, 'collect-tall' ); ?>><?php _e( 'Tall', 'collect'); ?></option>
			<option value="collect-square-large" <?php selected( $box_size, 'collect-square-large' ); ?>><?php _e( 'Large Square', 'collect'); ?></option>
		</select>
		<?php
	}

	/**
	 * Save post custom fields
	 *
	 * This function is attached to the 'pre_post_update' action hook.
	 *
	 * @since 1.0.0
	 */
	public function pre_post_update( $post_id ) {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		// Check if quick edit
		if ( ! empty( $_POST['_inline_edit'] ) && wp_verify_nonce( $_POST['_inline_edit'], 'inlineeditnonce' ) ) {
			return;
		}

		if ( ! empty( $_POST['collect_nonce'] ) && ! wp_verify_nonce( $_POST['collect_nonce'], 'collect_nonce' ) ) {
			return;
		}

		if ( ! empty( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
			if ( ! current_user_can( 'edit_page', $post_id ) ) {
				return;
			}
		} else {
			if ( ! current_user_can( 'edit_post', $post_id ) ) {
				return;
			}
		}

		// Sanitize
		$size_array = array( 'collect-square', 'collect-wide', 'collect-tall', 'collect-square-large' );
		$collect_box_size = ( isset( $_POST['collect_box_size'] ) && in_array( $_POST['collect_box_size'], $size_array ) ) ? $_POST['collect_box_size'] : '';

		$this->save_meta_value( $post_id, 'collect_box_size', $collect_box_size );
	}

	/**
	 * Save meta helper function
	 *
	 * @param	int $post_id	The post id
	 * @param	string $name	The custom field meta key
	 *
	 * @since 1.0.0
	 */
	public function save_meta_value( $post_id, $name, $value ) {
		if ( $value ) {
			update_post_meta( $post_id, $name, $value );
		} else {
			delete_post_meta( $post_id, $name );
		}
	}
}
$collect_metaboxes = new Collect_Metaboxes;